@@ -331,7 +331,7 @@ class RawToPrep(CompositeModule):
             'min_amp': amp,
         }
 
-    def _build_prep_configs(self, meter, merge_output, polar, freq):
+    def _build_prep_configs(self, meter, merge_output, polar):
 
         def _compute_rotations(meter):
             if(meter['type'] == 'noncontact'):
@@ -378,7 +378,6 @@ class RawToPrep(CompositeModule):
             'scale_factor': _compute_scale_factor(meter),
             'merge': merge_output,
             'polar': polar,
-            'line_freq': freq,
             'samp_freq': _compute_sampling_frequency(meter),
             'goertzel': _compute_goertzel(meter)
         }
