@@ -1,4 +1,3 @@
-
 import unittest
 import asyncio
 import argparse
@@ -10,7 +9,6 @@ from joule import LocalPipe
 from nilm.filters import rawtoprep
 from nilm.filters import prep, sinefit, reconstructor
 
-
 CONFIG_PATH = os.path.join(os.path.dirname(
     __file__), 'rawtoprep_files', 'meters.yml')
 CAL_DIR_PATH = os.path.join(os.path.dirname(
@@ -28,7 +26,7 @@ class MockReconstructor(reconstructor.Reconstructor):
         # print(raw_sarray)
         await iv.write(raw_sarray)
 
-        
+
 class MockSinefit(sinefit.Sinefit):
     async def run(self, parsed_args, inputs, outputs):
         iv = inputs['iv']
@@ -39,7 +37,7 @@ class MockSinefit(sinefit.Sinefit):
         # print(iv_sarray)
         await zc.write(iv_sarray)
 
-        
+
 class MockPrep(prep.Prep):
     async def run(self, parsed_args, inputs, outputs):
         zc = inputs['zero_crossings']
@@ -53,14 +51,20 @@ class MockPrep(prep.Prep):
         # print(iv_sarray)
         await prep.write(iv_sarray)
 
-        
+
 class TestRawToPrep(unittest.TestCase):
+    def setUp(self):
+        self.loop = asyncio.new_event_loop()
+        self.loop.set_debug=True
+        asyncio.set_event_loop(self.loop)
+
+    def tearDown(self):
+        self.loop.close()
 
     @mock.patch("nilm.filters.rawtoprep.Prep", new=MockPrep)
     @mock.patch("nilm.filters.rawtoprep.Sinefit", new=MockSinefit)
     @mock.patch("nilm.filters.rawtoprep.Reconstructor", new=MockReconstructor)
     def test_configures_pipes_to_filters(self):
-
         # input
         npipe_raw = LocalPipe(layout="uint8_1", name="raw")
         npipe_raw.write_nowait(np.array([[1.0, 0]]))
@@ -76,21 +80,25 @@ class TestRawToPrep(unittest.TestCase):
                                   frequency=60,
                                   min_voltage=10)
         my_filter = rawtoprep.RawToPrep()
-        loop = asyncio.new_event_loop()
-        asyncio.set_event_loop(loop)
-        tasks = loop.run_until_complete(my_filter.setup(
-            args,
-            {"raw": npipe_raw},
-            {"iv": npipe_iv,
-             "zero_crossings": npipe_zc,
-             "prep": npipe_prep},
-            loop
-        ))
-        loop.run_until_complete(asyncio.gather(*tasks))
-        loop.close()
-        iv_result = npipe_iv.read_nowait().tolist()
-        zc_result = npipe_zc.read_nowait().tolist()
-        prep_result = npipe_prep.read_nowait().tolist()
+
+        async def runner():
+            tasks = await my_filter.setup(
+                args,
+                {"raw": npipe_raw},
+                {"iv": npipe_iv,
+                 "zero_crossings": npipe_zc,
+                 "prep": npipe_prep}
+            )
+            await asyncio.gather(*tasks)
+            await npipe_iv.close()
+            await npipe_zc.close()
+            await npipe_prep.close()
+            await npipe_raw.close()
+        loop = asyncio.get_event_loop()
+        loop.run_until_complete(runner())
+        iv_result = npipe_iv.read_nowait(flatten=True).tolist()
+        zc_result = npipe_zc.read_nowait(flatten=True).tolist()
+        prep_result = npipe_prep.read_nowait(flatten=True).tolist()
         np.testing.assert_array_equal(np.array([[1.0, 1]]), iv_result)
         np.testing.assert_array_equal(np.array([[1.0, 2]]), zc_result)
         np.testing.assert_array_equal(np.array([[1.0, 3]]), prep_result)
